// Import necessary functions from the d3-geo package
import { geoMercator, geoPath } from 'd3';

// Initialize the Mercator projection
// The Mercator projection is commonly used for maps that require representing direction accurately,
// but it distorts sizes, especially near the poles.
const projection = geoMercator();

// Marks component that takes geographic data as props
// `data` contains two properties: `land` and `interiors`.
// `land` represents the landmasses to be drawn, and `interiors` represent internal boundaries within these landmasses.
export const Marks = ({ data: { land, interiors } }) => {
  // Create a geoPath generator, which will convert GeoJSON into SVG path data.
  // `fitExtent` is used to scale and translate the projection to fit within the specified dimensions (940x380 pixels here) and at the specified offset (10x20 pixels from the top left).
  const path = geoPath(
    projection.fitExtent(
      [
        [10, 20], // Top-left corner of the SVG
        [940, 380], // Bottom-right corner of the SVG
      ],
      land, // GeoJSON object for landmasses
    ),
  );

  // Render the map as SVG paths
  return (
    <g className="marks">
      {/* Map over the `land.features` array to create an SVG path for each feature */}
      {land.features.map((feature) => (
        <path className={'feature'} d={path(feature)} />
      ))}
      {/* Draw the interiors (internal boundaries) as a separate path */}
      <path className={'interiors'} d={path(interiors)} />
    </g>
  );
};
